@@ -1,7 +1,7 @@
 /*  ===== actuar: an R package for Actuarial Science =====
  *
  *  Functions to calculate raw and limited moments for the Exponential
- *  distribution.
+ *  distribution. See ../R/ExponentialSupp.R for details.
  *
  *  AUTHORS: Mathieu Pigeon and Vincent Goulet <vincent.goulet@act.ulaval.ca>
  */
@@ -24,8 +24,6 @@ double mexp(double order, double scale, int give_log)
 
 double levexp(double limit, double scale, double order, int give_log)
 {
-    double u, tmp;
-
     if (!R_FINITE(scale) ||
 	!R_FINITE(order) ||
 	scale <= 0.0 ||
@@ -33,13 +31,27 @@ double levexp(double limit, double scale, double order, int give_log)
 	return R_NaN;
 
     if (limit <= 0.0)
-	return 0;
+	return 0.0;
+
+    double u, tmp;
 
     tmp = 1.0 + order;
-
     u = exp(log(limit) - log(scale));
 
     return R_pow(scale, order) * gammafn(tmp) *
 	pgamma(u, tmp, 1.0, 1, 0) +
 	R_VG__0(limit, order) * exp(-u);
 }
+
+double mgfexp(double x, double scale, int give_log)
+{
+    if (!R_FINITE(scale) ||
+	scale <= 0.0 ||
+	scale * x > 1.0)
+	return R_NaN;
+
+    if (x == 0.0)
+	return R_D_exp(0.0);
+
+    return R_D_exp(-log1p(-scale * x));
+}
