@@ -1,7 +1,7 @@
 /*  ===== actuar: an R package for Actuarial Science =====
  *
  *  Functions to calculate raw and limited moments for the Gamma
- *  distribution.
+ *  distribution. See ../R/GammaSupp.R for details.
  *
  *  AUTHORS: Mathieu Pigeon and Vincent Goulet <vincent.goulet@act.ulaval.ca>
  */
@@ -27,8 +27,6 @@ double mgamma(double order, double shape, double scale, int give_log)
 double levgamma(double limit, double shape, double scale, double order,
 		int give_log)
 {
-    double u, tmp;
-
     if (!R_FINITE(shape) ||
 	!R_FINITE(scale) ||
 	!R_FINITE(order) ||
@@ -38,13 +36,29 @@ double levgamma(double limit, double shape, double scale, double order,
 	return R_NaN;
 
     if (limit <= 0.0)
-	return 0;
+	return 0.0;
+
+    double u, tmp;
 
     tmp = order + shape;
-
     u = exp(log(limit) - log(scale));
 
     return R_pow(scale, order) * gammafn(tmp) *
 	pgamma(u, tmp, 1.0, 1, 0) / gammafn(shape) +
 	R_VG__0(limit, order) * pgamma(u, shape, 1.0, 0, 0);
 }
+
+double mgfgamma(double x, double shape, double scale, int give_log)
+{
+    if (!R_FINITE(shape) ||
+	!R_FINITE(scale) ||
+	shape <= 0.0 ||
+	scale <= 0.0 ||
+	scale * x > 1.)
+	return R_NaN;
+
+    if (x == 0.0)
+	return R_D_exp(0.0);
+
+    return R_D_exp(-shape * log1p(-scale * x));
+}
