@@ -2,8 +2,8 @@
  *
  *  Functions to compute density, cumulative distribution and quantile
  *  functions, raw and limited moments and to simulate random variates
- *  for the inverse exponential distribution. See ../R/invexp.R for
- *  details.
+ *  for the inverse exponential distribution. See ../R/InverseExponential.R
+ *  for details.
  *
  *  AUTHORS: Mathieu Pigeon and Vincent Goulet <vincent.goulet@act.ulaval.ca>
  */
@@ -87,7 +87,6 @@ double levinvexp(double limit, double scale, double order, int give_log)
     if (!R_FINITE(scale) ||
 	R_FINITE(order) ||
 	scale <= 0.0 ||
-	order <= 0.0 ||
 	order >= 1.0)
 	return R_NaN;
 
